<?php
/*
Plugin Name: Enhanced Video Uploader for YouTube
Plugin URI: http://www.smartechwebsolutions.com/enhaced-video-uploader-youtube
Description: A simple WordPress plugin that allows users to upload YouTube videos directly from the admin dashboard by entering the video link.
Version: 2.0
Author: Prasad Bhambale
Author URI: http://www.smartechwebsolutions.com
License: GPLv2 or later
License URI: https://www.gnu.org/licenses/gpl-2.0.html
*/



// Ensure direct access is blocked
if (!defined('ABSPATH')) {
    exit;
}

// Add menu item and register settings
add_action('admin_menu', 'youtube_video_uploader_menu');
add_action('admin_init', 'youtube_video_settings_init');

// Register shortcodes for slider and grid
add_shortcode('youtube_video_slider', 'render_youtube_video_slider');
add_shortcode('youtube_video_grid', 'render_youtube_video_grid');

// Initialize plugin settings
function youtube_video_settings_init() {
    register_setting('youtube_video_settings', 'youtube_api_key');
}

// Add admin menu
function youtube_video_uploader_menu() {
    add_menu_page('YouTube Video Uploader', 'YouTube Videos', 'manage_options', 'youtube-video-uploader', 'youtube_video_uploader_page', 'dashicons-video-alt3');
    add_submenu_page('youtube-video-uploader', 'Settings', 'Settings', 'manage_options', 'youtube-video-settings', 'youtube_video_settings_page');
}

// Fetch video details from YouTube API
function get_youtube_video_details($youtube_url) {
    $api_key = get_option('youtube_api_key');
    if (empty($api_key)) return false;

    // Extract video ID from URL
    preg_match('/(?:youtube\.com\/(?:[^\/]+\/.+\/|(?:v|e(?:mbed)?)\/|.*[?&]v=)|youtu\.be\/)([^"&?\/\s]{11})/', $youtube_url, $matches);
    if (empty($matches[1])) return false;

    $video_id = $matches[1];
    $api_url = "https://www.googleapis.com/youtube/v3/videos?id={$video_id}&key={$api_key}&part=snippet";
    
    $response = wp_remote_get($api_url);
    if (is_wp_error($response)) return false;

    $data = json_decode(wp_remote_retrieve_body($response), true);
    if (empty($data['items'][0])) return false;

    return [
        'title' => $data['items'][0]['snippet']['title'],
        'thumbnail' => $data['items'][0]['snippet']['thumbnails']['high']['url'],
        'video_id' => $video_id
    ];
}

function youtube_video_uploader_page() {
    if (isset($_POST['submit_youtube_video'])) {
        $youtube_link = esc_url($_POST['youtube_link']);
        if (!empty($youtube_link)) {
            $video_details = get_youtube_video_details($youtube_link);
            if ($video_details) {
                $videos = get_option('youtube_videos', []);
                $videos[] = [
                    'url' => $youtube_link,
                    'title' => $video_details['title'],
                    'thumbnail' => $video_details['thumbnail'],
                    'video_id' => $video_details['video_id']
                ];
                update_option('youtube_videos', $videos);
                add_settings_error('youtube_video_messages', 'video_added', 'Video successfully added!', 'success');
            } else {
                add_settings_error('youtube_video_messages', 'video_error', 'Could not fetch video details. Please check your API key and video URL.', 'error');
            }
        }
    }

    if (isset($_GET['delete_video'])) {
        $videos = get_option('youtube_videos', []);
        $delete_index = intval($_GET['delete_video']);
        if (isset($videos[$delete_index])) {
            unset($videos[$delete_index]);
            update_option('youtube_videos', array_values($videos));
            add_settings_error('youtube_video_messages', 'video_deleted', 'Video successfully deleted!', 'success');
        }
    }

    ?>
    <div class="wrap youtube-uploader-wrap">
        <h1 class="wp-heading-inline">YouTube Video Uploader</h1>
        
        <?php settings_errors('youtube_video_messages'); ?>

        <!-- Shortcodes Information Card -->
        <div class="youtube-shortcodes-card">
            <h2>Available Shortcodes</h2>
            <div class="shortcode-grid">
                <div class="shortcode-item">
                    <h3>Slider Display</h3>
                    <div class="shortcode-content">
                        <code class="shortcode-text">[youtube_video_slider theme="light" interval="5000"]</code>
                        <button class="copy-shortcode button" data-shortcode="[youtube_video_slider theme=&quot;light&quot; interval=&quot;5000&quot;]">
                            Copy
                        </button>
                    </div>
                    <p class="shortcode-description">
                        Displays videos in an auto-playing slider. Options:
                        <br>• theme: "light" or "dark"
                        <br>• interval: Slide duration in milliseconds
                    </p>
                </div>
                <div class="shortcode-item">
                    <h3>Grid Display</h3>
                    <div class="shortcode-content">
                        <code class="shortcode-text">[youtube_video_grid columns="3" theme="light" max_videos="6"]</code>
                        <button class="copy-shortcode button" data-shortcode="[youtube_video_grid columns=&quot;3&quot; theme=&quot;light&quot; max_videos=&quot;6&quot;]">
                            Copy
                        </button>
                    </div>
                    <p class="shortcode-description">
                        Displays videos in a responsive grid. Options:
                        <br>• columns: Number of columns (1-4)
                        <br>• theme: "light" or "dark"
                        <br>• max_videos: Maximum videos to display
                    </p>
                </div>
            </div>
        </div>

       <!-- Add Video Form -->
<div class="youtube-form-card">
    <h2>Add New Video</h2>
    <form method="POST" action="">
        <div class="form-row">
            <div class="form-group">
                <label for="youtube_link">YouTube Video URL:</label>
                <input type="url" id="youtube_link" name="youtube_link" class="regular-text" 
                       placeholder="Paste the full YouTube video URL here" required>
            </div>
            <?php submit_button('Add Video', 'primary', 'submit_youtube_video', false); ?>
        </div>
    </form>
</div>


        <!-- Managed Videos Section -->
        <div class="youtube-videos-section">
            <h2>Managed Videos</h2>
            <div class="youtube-videos-grid">
                <?php
                $videos = get_option('youtube_videos', []);
                if (!empty($videos)) :
                    foreach ($videos as $index => $video) : ?>
                        <div class="youtube-video-card">
                            <div class="video-thumbnail">
                                <img src="<?php echo esc_url($video['thumbnail']); ?>" 
                                     alt="<?php echo esc_attr($video['title']); ?>">
                                <div class="video-overlay">
                                    <a href="<?php echo esc_url($video['url']); ?>" 
                                       target="_blank" 
                                       class="button button-secondary">
                                        Preview
                                    </a>
                                </div>
                            </div>
                            <div class="video-details">
                                <h3><?php echo esc_html($video['title']); ?></h3>
                                <div class="video-actions">
                                    <a href="?page=youtube-video-uploader&delete_video=<?php echo $index; ?>" 
                                       class="button button-link-delete"
                                       onclick="return confirm('Are you sure you want to delete this video?');">
                                        Delete
                                    </a>
                                </div>
                            </div>
                        </div>
                    <?php endforeach;
                else : ?>
                    <div class="no-videos-message">
                        <p>No videos added yet. Use the form above to add your first video!</p>
                    </div>
                <?php endif; ?>
            </div>
        </div>
    </div>

    <style>
        .youtube-form-card {
            max-width: 100%; /* Set a max width for larger screens */
            margin: 0 auto; /* Center the form */
            padding: 20px;
        }

        .form-row {
            display: flex;
            flex-wrap: wrap; /* Allow items to wrap on smaller screens */
            align-items: center;
        }

        .form-group {
            flex: 1; /* Make the input flexible */
            margin-right: 10px; /* Space between the input and button */
        }

        .form-group label {
            margin-right: 5px; /* Space between label and input */
        }

        .form-group input {
            min-width: 800px; /* Set a minimum width */
        }

        @media (max-width: 768px) { /* For smaller screens */
            .form-row {
                flex-direction: column; /* Stack elements vertically */
            }

            .form-group {
                margin-right: 0; /* Remove right margin */
                margin-bottom: 10px; /* Space below each group */
            }

            .form-group input {
                width: auto; /* Reset width for better fit */
            }
        }

       

        /* Cards Styling */
        .youtube-shortcodes-card,
        .youtube-form-card {
            background: #fff;
            border: 1px solid #ccd0d4;
            border-radius: 4px;
            padding: 20px;
            margin-bottom: 20px;
            box-shadow: 0 1px 3px rgba(0,0,0,0.1);
        }

        /* Shortcodes Grid */
        .shortcode-grid {
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(300px, 1fr));
            gap: 20px;
            margin-top: 15px;
        }

        .shortcode-item {
            background: #f8f9fa;
            border: 1px solid #e2e4e7;
            border-radius: 4px;
            padding: 15px;
        }

        .shortcode-item h3 {
            margin: 0 0 10px;
            color: #1e1e1e;
        }

        .shortcode-content {
            display: flex;
            gap: 10px;
            background: #fff;
            padding: 10px;
            border: 1px solid #e2e4e7;
            border-radius: 4px;
            margin: 10px 0;
        }

        .shortcode-text {
            flex: 1;
            padding: 8px;
            background: #f1f1f1;
            border-radius: 3px;
            font-size: 13px;
            line-height: 1.4;
            overflow-x: auto;
        }

        .copy-shortcode {
            white-space: nowrap;
        }

        .shortcode-description {
            margin: 10px 0 0;
            font-size: 13px;
            color: #646970;
            line-height: 1.5;
        }

    

        /* Videos Grid */
        .youtube-videos-grid {
            display: grid;
            grid-template-columns: repeat(auto-fill, minmax(300px, 1fr));
            gap: 20px;
            margin-top: 20px;
        }

        .youtube-video-card {
            background: #fff;
            border: 1px solid #ccd0d4;
            border-radius: 4px;
            overflow: hidden;
            transition: transform 0.2s ease;
        }

        .youtube-video-card:hover {
            transform: translateY(-2px);
        }

        .video-thumbnail {
            position: relative;
            padding-top: 56.25%;
            background: #f0f0f0;
        }

        .video-thumbnail img {
            position: absolute;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            object-fit: cover;
        }

        .video-overlay {
            position: absolute;
            top: 0;
            left: 0;
            right: 0;
            bottom: 0;
            background: rgba(0,0,0,0.5);
            display: flex;
            align-items: center;
            justify-content: center;
            opacity: 0;
            transition: opacity 0.2s ease;
        }

        .video-thumbnail:hover .video-overlay {
            opacity: 1;
        }

        .video-details {
            padding: 15px;
        }

        .video-details h3 {
            margin: 0 0 10px;
            font-size: 14px;
            line-height: 1.4;
        }

        .video-actions {
            display: flex;
            justify-content: flex-end;
            gap: 10px;
        }

        .no-videos-message {
            grid-column: 1 / -1;
            text-align: center;
            padding: 40px;
            background: #fff;
            border: 1px solid #ccd0d4;
            border-radius: 4px;
        }
    </style>

    <script>
    document.addEventListener('DOMContentLoaded', function() {
        // Handle shortcode copying
        document.querySelectorAll('.copy-shortcode').forEach(button => {
            button.addEventListener('click', function() {
                const shortcode = this.dataset.shortcode;
                navigator.clipboard.writeText(shortcode).then(() => {
                    const originalText = this.textContent;
                    this.textContent = 'Copied!';
                    this.classList.add('button-primary');
                    
                    setTimeout(() => {
                        this.textContent = originalText;
                        this.classList.remove('button-primary');
                    }, 2000);
                });
            });
        });

        // Add success message fade out
        setTimeout(() => {
            const messages = document.querySelectorAll('.notice');
            messages.forEach(message => {
                message.style.transition = 'opacity 0.5s ease';
                message.style.opacity = '0';
                setTimeout(() => message.remove(), 500);
            });
        }, 3000);
    });
    </script>
    <?php
}

// Settings page
function youtube_video_settings_page() {
    ?>
    <div class="wrap">
        <h1>YouTube Video Settings</h1>
        <form method="post" action="options.php">
            <?php
            settings_fields('youtube_video_settings');
            do_settings_sections('youtube_video_settings');
            ?>
            <table class="form-table">
                <tr>
                    <th scope="row"><label for="youtube_api_key">YouTube API Key</label></th>
                    <td>
                        <input type="text" id="youtube_api_key" name="youtube_api_key" 
                               value="<?php echo esc_attr(get_option('youtube_api_key')); ?>" class="regular-text">
                        <p class="description">Enter your YouTube Data API key</p>
                    </td>
                </tr>
            </table>
            <?php submit_button(); ?>
        </form>
    </div>
    <?php
}

function render_youtube_video_slider($atts) {
    // Parse shortcode attributes with autoplay settings
    $attributes = shortcode_atts(array(
        'interval' => 5000, // Autoplay interval in milliseconds
        'theme' => 'light'
    ), $atts);

    // Fetch videos
    $videos = get_option('youtube_videos', []);
    $total_videos = count($videos);
    
    if (empty($videos)) {
        return '<p class="youtube-slider-empty">No videos found.</p>';
    }

    ob_start();
    ?>
    <div class="youtube-slider-container <?php echo esc_attr($attributes['theme']); ?>-theme">
        <div class="youtube-slider-wrapper">
            <div class="youtube-slider" data-interval="<?php echo esc_attr($attributes['interval']); ?>">
                <?php
                foreach ($videos as $index => $video) {
                    $video_id = esc_attr($video['video_id']);
                    $thumbnail = esc_url($video['thumbnail'] ?? '');
                    $title = esc_html($video['title'] ?? '');
                    $video_url = "https://www.youtube.com/watch?v=$video_id"; // YouTube video URL
                    ?>
                    <div class="youtube-slide">
                        <div class="youtube-slide-content">
                            <div class="youtube-thumbnail-container">
                                <a href="<?php echo $video_url; ?>" target="_blank" class="youtube-play-link">
                                    <img src="<?php echo $thumbnail; ?>" alt="<?php echo $title; ?>" loading="lazy">
                                    <div class="youtube-play-button">
                                        <svg viewBox="0 0 24 24">
                                            <path d="M8 5v14l11-7z" fill="currentColor"/>
                                        </svg>
                                    </div>
                                </a>
                            </div>
                            <h3 class="youtube-video-title"><?php echo $title; ?></h3>
                        </div>
                    </div>
                    <?php
                }
                ?>
            </div>
        </div>
        
        <!-- Progress bar for autoplay visualization -->
        <div class="youtube-slider-progress">
            <div class="youtube-slider-progress-bar"></div>
        </div>
    </div>

    <style>
        .youtube-slider-container {
            --yt-spacing: clamp(16px, 2vw, 24px);
            --yt-radius: 12px;
            --yt-transition: 0.3s cubic-bezier(0.4, 0, 0.2, 1);
            --yt-accent: #ff0000;
            position: relative;
            max-width: 1200px;
            margin: 0 auto;
            padding: var(--yt-spacing);
        }

        .youtube-slider-wrapper {
            position: relative;
            overflow: hidden;
            border-radius: var(--yt-radius);
            background: var(--yt-slide-bg, #fff);
            box-shadow: 0 4px 12px rgba(0, 0, 0, 0.1);
        }

        .youtube-slider {
            display: flex;
            transition: transform var(--yt-transition);
        }

        .youtube-slide {
            flex: 0 0 100%; /* Default: Mobile - 1 video */
            padding: 0 var(--yt-spacing);
            
            @media (min-width: 768px) {
                flex: 0 0 50%; /* Tablet - 2 videos */
            }
            
            @media (min-width: 1024px) {
                flex: 0 0 33.333%; /* Desktop - 3 videos */
            }
        }

        .youtube-slide-content {
            background: var(--yt-slide-bg, #fff);
            border-radius: var(--yt-radius);
            overflow: hidden;
            transition: transform var(--yt-transition);
        }

        .youtube-thumbnail-container {
            position: relative;
            padding-top: 56.25%; /* 16:9 Aspect Ratio */
            background: #f0f0f0;
            overflow: hidden;
        }

        .youtube-thumbnail-container img {
            position: absolute;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            object-fit: cover;
            transition: transform var(--yt-transition);
        }

        .youtube-play-button {
            position: absolute;
            top: 50%;
            left: 50%;
            transform: translate(-50%, -50%);
            width: 48px;
            height: 48px;
            background: var(--yt-accent);
            border-radius: 50%;
            display: flex;
            align-items: center;
            justify-content: center;
            color: white;
            opacity: 0.9;
            transition: opacity var(--yt-transition);
        }

        .youtube-play-button svg {
            width: 24px;
            height: 24px;
        }

        .youtube-video-title {
            margin: var(--yt-spacing);
            font-size: clamp(14px, 1vw, 16px);
            line-height: 1.4;
            color: var(--yt-title-color, #1a1a1a);
            display: -webkit-box;
            -webkit-line-clamp: 2;
            -webkit-box-orient: vertical;
            overflow: hidden;
        }

        /* Progress bar styles */
        .youtube-slider-progress {
            position: absolute;
            bottom: 0;
            left: 0;
            width: 100%;
            height: 4px;
            background: rgba(0, 0, 0, 0.1);
            overflow: hidden;
        }

        .youtube-slider-progress-bar {
            width: 100%;
            height: 100%;
            background: var(--yt-accent);
            transform: translateX(-100%);
        }

        /* Dark theme */
        .dark-theme {
            --yt-slide-bg: #1a1a1a;
            --yt-title-color: #ffffff;
            background: #121212;
        }
    </style>

    <script>
    document.addEventListener('DOMContentLoaded', function() {
        const sliderContainers = document.querySelectorAll('.youtube-slider-container');
        
        sliderContainers.forEach(container => {
            const slider = container.querySelector('.youtube-slider');
            const slides = container.querySelectorAll('.youtube-slide');
            const progressBar = container.querySelector('.youtube-slider-progress-bar');
            
            let currentSlide = 0;
            let isTransitioning = false;
            const interval = parseInt(slider.dataset.interval) || 5000;
            
            function getSlidesPerView() {
                const width = window.innerWidth;
                if (width >= 1024) return 3;
                if (width >= 768) return 2;
                return 1;
            }
            
            function getTotalSlides() {
                return Math.ceil(slides.length / getSlidesPerView());
            }
            
            function goToSlide(index) {
                if (isTransitioning) return;
                
                const totalSlides = getTotalSlides();
                currentSlide = (index + totalSlides) % totalSlides;
                
                const offset = -(currentSlide * (100 / getSlidesPerView()));
                slider.style.transform = `translateX(${offset}%)`;
                
                isTransitioning = true;
                setTimeout(() => {
                    isTransitioning = false;
                }, 300); // Match transition duration
            }
            
            function startProgressBar() {
                progressBar.style.transition = `transform ${interval}ms linear`;
                progressBar.style.transform = 'translateX(0)';
                
                setTimeout(() => {
                    progressBar.style.transition = 'none';
                    progressBar.style.transform = 'translateX(-100%)';
                    
                    // Small delay before next slide
                    setTimeout(() => {
                        goToSlide(currentSlide + 1);
                        startProgressBar();
                    }, 50);
                }, interval);
            }
            
            // Initialize autoplay
            function initAutoplay() {
                goToSlide(0);
                startProgressBar();
            }
            
            // Handle window resize
            let resizeTimer;
            window.addEventListener('resize', () => {
                clearTimeout(resizeTimer);
                resizeTimer = setTimeout(() => {
                    const totalSlides = getTotalSlides();
                    if (currentSlide >= totalSlides) {
                        currentSlide = 0;
                    }
                    goToSlide(currentSlide);
                }, 250);
            });
            
            // Handle visibility change
            document.addEventListener('visibilitychange', () => {
                if (document.hidden) {
                    progressBar.style.animationPlayState = 'paused';
                } else {
                    progressBar.style.animationPlayState = 'running';
                }
            });
            
            // Initialize the slider
            initAutoplay();
            
            // Pause on hover (optional)
            container.addEventListener('mouseenter', () => {
                progressBar.style.animationPlayState = 'paused';
            });
            
            container.addEventListener('mouseleave', () => {
                progressBar.style.animationPlayState = 'running';
            });
        });
    });
    </script>
    <?php
    
    return ob_get_clean();
}


function render_youtube_video_grid($atts) {
    // Parse shortcode attributes with defaults
    $attributes = shortcode_atts(array(
        'columns' => 3,
        'max_videos' => -1,
        'category' => '',
        'theme' => 'light' // New attribute for theme selection
    ), $atts);
    
    // Sanitize attributes
    $columns = absint($attributes['columns']);
    $max_videos = intval($attributes['max_videos']);
    $category = sanitize_text_field($attributes['category']);
    $theme = sanitize_text_field($attributes['theme']);
    
    // Fetch and filter videos (same as before)
    $videos = get_option('youtube_videos', []);
    
    if (!empty($category) && !empty($videos)) {
        $videos = array_filter($videos, function($video) use ($category) {
            return isset($video['category']) && $video['category'] === $category;
        });
    }
    
    if ($max_videos > 0 && count($videos) > $max_videos) {
        $videos = array_slice($videos, 0, $max_videos);
    }
    
    ob_start();
    
    if (!empty($videos)) {
        // Add theme class to container
        $theme_class = ($theme === 'dark') ? 'youtube-grid-dark' : 'youtube-grid-light';
        echo "<div class='youtube-grid-container {$theme_class}'>";
        echo "<div class='youtube-grid' data-columns='" . esc_attr($columns) . "'>";
        
        foreach ($videos as $video) {
            if (!isset($video['video_id']) || !isset($video['thumbnail']) || !isset($video['title'])) {
                continue;
            }
            
            $video_url = esc_url("https://www.youtube.com/watch?v={$video['video_id']}");
            $thumbnail = esc_url($video['thumbnail']);
            $title = esc_html($video['title']);
            $duration = isset($video['duration']) ? esc_html($video['duration']) : '';
            $views = isset($video['views']) ? number_format($video['views']) : '';
            
            echo "<div class='youtube-grid-item'>";
            echo "  <div class='youtube-thumbnail-wrapper'>";
            echo "    <img src='data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7' 
                          data-src='{$thumbnail}' 
                          alt='{$title}' 
                          class='lazy' />";
            echo "    <a href='{$video_url}' target='_blank' rel='noopener' class='youtube-play-overlay'>";
            echo "      <div class='youtube-play-button'>";
            echo "        <svg viewBox='0 0 24 24'><path fill='currentColor' d='M8 5v14l11-7z'/></svg>";
            echo "      </div>";
            if ($duration) {
                echo "    <span class='youtube-duration'>{$duration}</span>";
            }
            echo "    </a>";
            echo "  </div>";
            echo "  <div class='youtube-content'>";
            echo "    <h3>{$title}</h3>";
            if ($views) {
                echo "  <span class='youtube-views'>{$views} views</span>";
            }
            echo "    <a href='{$video_url}' class='youtube-watch-button' target='_blank' rel='noopener'>";
            echo "      <span>Watch Now</span>";
            echo "      <svg viewBox='0 0 24 24'><path fill='currentColor' d='M5 12h14M13 5l7 7-7 7'/></svg>";
            echo "    </a>";
            echo "  </div>";
            echo "</div>";
        }
        
        echo "</div>";
        echo "</div>";
        
        // Modern styling with CSS variables for theming
        ?>
        <style>
            :root {
                --yt-grid-spacing: clamp(16px, 2vw, 30px);
                --yt-card-radius: 12px;
                --yt-animation-duration: 0.3s;
                --yt-shadow-color: rgba(0, 0, 0, 0.1);
                --yt-overlay-color: rgba(0, 0, 0, 0.5);
                --yt-accent-color: #ff0000;
                --yt-hover-accent: #cc0000;
            }

            .youtube-grid-container {
                font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Oxygen-Sans, Ubuntu, Cantarell, sans-serif;
            }

            .youtube-grid {
                display: grid;
                grid-template-columns: repeat(<?php echo $columns; ?>, 1fr);
                gap: var(--yt-grid-spacing);
                margin: var(--yt-grid-spacing) 0;
            }
            
            /* Responsive grid adjustments with modern breakpoints */
            @media (max-width: 1200px) {
                .youtube-grid { grid-template-columns: repeat(3, 1fr); }
            }
            
            @media (max-width: 900px) {
                .youtube-grid { grid-template-columns: repeat(2, 1fr); }
            }
            
            @media (max-width: 600px) {
                .youtube-grid { grid-template-columns: 1fr; }
            }
            
            .youtube-grid-item {
                position: relative;
                background: var(--yt-card-bg, #fff);
                border-radius: var(--yt-card-radius);
                overflow: hidden;
                transition: transform var(--yt-animation-duration) cubic-bezier(0.4, 0, 0.2, 1),
                            box-shadow var(--yt-animation-duration) cubic-bezier(0.4, 0, 0.2, 1);
                box-shadow: 0 4px 6px var(--yt-shadow-color);
            }
            
            .youtube-grid-item:hover {
                transform: translateY(-4px) scale(1.02);
                box-shadow: 0 12px 20px var(--yt-shadow-color);
            }
            
            .youtube-thumbnail-wrapper {
                position: relative;
                padding-top: 56.25%;
                background: #f0f0f0;
                overflow: hidden;
            }
            
            .youtube-grid-item img {
                position: absolute;
                top: 0;
                left: 0;
                width: 100%;
                height: 100%;
                object-fit: cover;
                transition: transform var(--yt-animation-duration) ease;
            }
            
            .youtube-grid-item:hover img {
                transform: scale(1.05);
            }
            
            .youtube-play-overlay {
                position: absolute;
                top: 0;
                left: 0;
                right: 0;
                bottom: 0;
                background: var(--yt-overlay-color);
                opacity: 0;
                transition: opacity var(--yt-animation-duration) ease;
                display: flex;
                align-items: center;
                justify-content: center;
            }
            
            .youtube-grid-item:hover .youtube-play-overlay {
                opacity: 1;
            }
            
            .youtube-play-button {
                width: 60px;
                height: 60px;
                background: var(--yt-accent-color);
                border-radius: 50%;
                display: flex;
                align-items: center;
                justify-content: center;
                transition: transform var(--yt-animation-duration) ease;
            }
            
            .youtube-play-button svg {
                width: 30px;
                height: 30px;
                color: white;
            }
            
            .youtube-grid-item:hover .youtube-play-button {
                transform: scale(1.1);
            }
            
            .youtube-duration {
                position: absolute;
                bottom: 12px;
                right: 12px;
                background: rgba(0, 0, 0, 0.8);
                color: white;
                padding: 4px 8px;
                border-radius: 4px;
                font-size: 12px;
                font-weight: 500;
            }
            
            .youtube-content {
                padding: 20px;
            }
            
            .youtube-content h3 {
                margin: 0 0 10px;
                font-size: clamp(16px, 1.5vw, 18px);
                line-height: 1.4;
                font-weight: 600;
                color: var(--yt-title-color, #1a1a1a);
                display: -webkit-box;
                -webkit-line-clamp: 2;
                -webkit-box-orient: vertical;
                overflow: hidden;
            }
            
            .youtube-views {
                display: block;
                font-size: 14px;
                color: var(--yt-text-secondary, #666);
                margin-bottom: 15px;
            }
            
            .youtube-watch-button {
                display: flex;
                align-items: center;
                justify-content: center;
                gap: 8px;
                background: var(--yt-accent-color);
                color: white;
                text-decoration: none;
                padding: 12px 24px;
                border-radius: 6px;
                font-weight: 500;
                transition: background var(--yt-animation-duration) ease;
            }
            
            .youtube-watch-button:hover {
                background: var(--yt-hover-accent);
            }
            
            .youtube-watch-button svg {
                width: 20px;
                height: 20px;
                transition: transform var(--yt-animation-duration) ease;
            }
            
            .youtube-watch-button:hover svg {
                transform: translateX(4px);
            }
            
            /* Dark theme styles */
            .youtube-grid-dark {
                --yt-card-bg: #1a1a1a;
                --yt-title-color: #ffffff;
                --yt-text-secondary: #a0a0a0;
                --yt-shadow-color: rgba(0, 0, 0, 0.3);
                background: #121212;
            }
            
            /* Loading animation */
            .youtube-grid-item.loading {
                animation: cardLoading 1.5s infinite;
            }
            
            @keyframes cardLoading {
                0% { opacity: 1; }
                50% { opacity: 0.7; }
                100% { opacity: 1; }
            }
        </style>
        <script>
        document.addEventListener('DOMContentLoaded', function() {
            // Enhanced lazy loading with fade-in animation
            const lazyImages = document.querySelectorAll('img.lazy');
            
            if ('IntersectionObserver' in window) {
                const imageObserver = new IntersectionObserver((entries, observer) => {
                    entries.forEach(entry => {
                        if (entry.isIntersecting) {
                            const img = entry.target;
                            img.src = img.dataset.src;
                            img.style.opacity = 0;
                            
                            img.onload = () => {
                                img.style.transition = 'opacity 0.5s ease';
                                img.style.opacity = 1;
                                img.classList.remove('lazy');
                            };
                            
                            observer.unobserve(img);
                        }
                    });
                }, {
                    rootMargin: '50px',
                    threshold: 0.1
                });
                
                lazyImages.forEach(img => imageObserver.observe(img));
            }
            
            // Add loading animation to cards
            document.querySelectorAll('.youtube-grid-item').forEach(card => {
                card.classList.add('loading');
                setTimeout(() => card.classList.remove('loading'), 1000);
            });
        });
        </script>
        <?php
    } else {
        echo '<div class="youtube-grid-empty">
                <svg viewBox="0 0 24 24" width="48" height="48">
                    <path fill="currentColor" d="M19 5v14H5V5h14m0-2H5c-1.1 0-2 .9-2 2v14c0 1.1.9 2 2 2h14c1.1 0 2-.9 2-2V5c0-1.1-.9-2-2-2zm-5 14v-3h-3v-2h3V9l4 4-4 4z"/>
                </svg>
                <p>No videos found</p>
              </div>';
    }
    
    return ob_get_clean();
}


?>
